package com.jasamedika.medifirst2000.vo.custom;

import java.util.ArrayList;

import com.fasterxml.jackson.annotation.JsonProperty;

public class BridgeSisRuteDataVO {
	@JsonProperty("NORM")
	private String norm;
	
	@JsonProperty("NAMA")
	private String nama;
	
	@JsonProperty("TEMPAT_LAHIR")
	private String tempatLahir;
	
	@JsonProperty("TANGGAL_LAHIR")
	private String tanggalLahir;
	
	@JsonProperty("JENIS_KELAMIN")
	private String jenisKelamin;
	
	@JsonProperty("ALAMAT")
	private String alamat;
	
	@JsonProperty("KARTUIDENTITAS")
	private ArrayList<BridgeSisRuteKartuIdentitasVO> kartuIdentitas;
	
	@JsonProperty("KARTUASURANSI")
	private ArrayList<BridgeSisRuteKartuAsuransiVO> kartuAsuransi;
	
	@JsonProperty("KONTAK")
	private ArrayList<BridgeSisRuteKontakVO> kontak;
	
	public BridgeSisRuteDataVO(){
		kartuIdentitas = new ArrayList <BridgeSisRuteKartuIdentitasVO>(); 
		kartuAsuransi= new ArrayList <BridgeSisRuteKartuAsuransiVO>();
		kontak= new ArrayList <BridgeSisRuteKontakVO>();
	}
	
	public void addKartuIdentitas(BridgeSisRuteKartuIdentitasVO x){
		kartuIdentitas .add(x);
	}
	public ArrayList<BridgeSisRuteKartuIdentitasVO> getKartuIdentitas(){
		return kartuIdentitas;
	}

	public void addKartuAsuransi(BridgeSisRuteKartuAsuransiVO x){
		kartuAsuransi .add(x);
	}
	public ArrayList<BridgeSisRuteKartuAsuransiVO> getKartuAsuransi(){
		return kartuAsuransi;
	}

	public void addKontak(BridgeSisRuteKontakVO x){
		kontak .add(x);
	}
	public ArrayList<BridgeSisRuteKontakVO> getKontak(){
		return kontak;
	}

	public String getNorm() {
		return norm;
	}

	public void setNorm(String norm) {
		this.norm = norm;
	}

	public String getNama() {
		return nama;
	}

	public void setNama(String nama) {
		this.nama = nama;
	}

	public String getTempatLahir() {
		return tempatLahir;
	}

	public void setTempatLahir(String tempatLahir) {
		this.tempatLahir = tempatLahir;
	}

	public String getTanggalLahir() {
		return tanggalLahir;
	}

	public void setTanggalLahir(String tanggalLahir) {
		this.tanggalLahir = tanggalLahir;
	}

	public String getJenisKelamin() {
		return jenisKelamin;
	}

	public void setJenisKelamin(String jenisKelamin) {
		this.jenisKelamin = jenisKelamin;
	}

	public String getAlamat() {
		return alamat;
	}

	public void setAlamat(String alamat) {
		this.alamat = alamat;
	}
}
